***************
Release History
***************

.. Changelog entries should follow this format:

   version (release date)
   ======================

   ** section **

   - One-line description of change (link to Github issue/PR)

.. Changes should be organized in one of several sections:

   - API Changes
   - Improvements
   - Behavioural Changes
   - Bugfixes
   - Documentation

2.0.0 (January 15, 2015)
========================

Initial release of Nengo 2.0!
Supports Python 2.6+ and 3.3+.
Thanks to all of the contributors for making this possible!
